summarylogtreecommitdiffstats
path: root/weka.sh
diff options
context:
space:
mode:
Diffstat (limited to 'weka.sh')
-rwxr-xr-xweka.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/weka.sh b/weka.sh
index 7b70a33d9966..d18250d9406b 100755
--- a/weka.sh
+++ b/weka.sh
@@ -1,11 +1,11 @@
#! /bin/sh
# Note: the '-Xmx1g' flag is used to set the maximum memory that the java
# program is allowed. When working with large data sets, this number may need
# to be increased based on how much memory you wish to allow weka to have.
# Specifying command line arguments will override the defaults shown here.
-# Example: '-Xmx2g'
-DEFAULT_ARGS='-Xms32m -Xmx1g'
+# Example: '-Xmx4g'
+DEFAULT_ARGS='-Xms32m -Xmx2g'
if [ $# -gt 0 ]; then
ARGS="$@"
@@ -1,11 +1,11 @@
#! /bin/sh
-# Note: the '-Xmx1g' flag is used to set the maximum memory that the java
+# Note: the '-Xmx2g' flag is used to set the maximum memory that the java
# program is allowed. When working with large data sets, this number may need
# to be increased based on how much memory you wish to allow weka to have.